
From: Pavel Machek <pavel@ucw.cz>

Fix comments in swsusp.

Signed-off-by: Pavel Machek <pavel@suse.cz>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 kernel/power/power.h  |    2 +-
 kernel/power/swsusp.c |   10 +++++++---
 2 files changed, 8 insertions(+), 4 deletions(-)

diff -puN kernel/power/power.h~swsusp-fix-comments kernel/power/power.h
--- devel/kernel/power/power.h~swsusp-fix-comments	2005-09-15 00:00:18.000000000 -0700
+++ devel-akpm/kernel/power/power.h	2005-09-15 00:00:18.000000000 -0700
@@ -1,7 +1,7 @@
 #include <linux/suspend.h>
 #include <linux/utsname.h>
 
-/* With SUSPEND_CONSOLE defined, it suspend looks *really* cool, but
+/* With SUSPEND_CONSOLE defined suspend looks *really* cool, but
    we probably do not take enough locks for switching consoles, etc,
    so bad things might happen.
 */
diff -puN kernel/power/swsusp.c~swsusp-fix-comments kernel/power/swsusp.c
--- devel/kernel/power/swsusp.c~swsusp-fix-comments	2005-09-15 00:00:18.000000000 -0700
+++ devel-akpm/kernel/power/swsusp.c	2005-09-15 00:00:18.000000000 -0700
@@ -363,7 +363,7 @@ static void lock_swapdevices(void)
 }
 
 /**
- *	write_swap_page - Write one page to a fresh swap location.
+ *	write_page - Write one page to a fresh swap location.
  *	@addr:	Address we're writing.
  *	@loc:	Place to store the entry we used.
  *
@@ -863,6 +863,9 @@ static int alloc_image_pages(void)
 	return 0;
 }
 
+/* Free pages we allocated for suspend. Suspend pages are alocated
+ * before atomic copy, so we need to free them after resume.
+ */
 void swsusp_free(void)
 {
 	BUG_ON(PageNosave(virt_to_page(pagedir_save)));
@@ -1213,8 +1216,9 @@ static struct pbe * swsusp_pagedir_reloc
 		free_pagedir(pblist);
 		free_eaten_memory();
 		pblist = NULL;
-	}
-	else
+		/* Is this even worth handling? It should never ever happen, and we
+		   have just lost user's state, anyway... */
+	} else
 		printk("swsusp: Relocated %d pages\n", rel);
 
 	return pblist;
_
